[![Color fonts](https://see.fontimg.com/api/renderfont4/GO6zm/eyJyIjoiZHciLCJoIjoxODIsInciOjIwMDAsImZzIjo5MSwiZmdjIjoiIzIxQkNDNSIsImJnYyI6IiNGRkZGRkYifQ/T1BUSSBmb2xpbw/fattern.png)](https://www.fontspace.com/category/color)

--------------------------------------

![PyPI Version](https://img.shields.io/pypi/v/optifolio)
![License](https://img.shields.io/pypi/l/optifolio)

**OptiFolio** is a package for portfolio optimization.

-   Documentation: (COMING SOON) <https://optifolio.readthedocs.io>.

> **NOTE**
>
> This project is in early stage development, and can thus go through major changes.

Install
-------

OptiFolio can be installed from
[PyPI](https://pypi.org/project/optifolio/):

``` {.sourceCode .python}
pip install optifolio
```

Features
--------

-   **PortfolioOptimizer [object]:** Optimize your portfolio based on Sharpe Ratio.
    * **fit [method]:** Fits daily stock data into the optimizer. Generates annual measures.
    * **plot_efficient_frontier [method]:** Generates a plot for efficient frontier, optimal portfolio, and individual stocks.

